/*
 * @brief aux_io.h
 * Auxiliary functions for I/O UARTs
 *
 * @note
 * UNIVERSITAT OBERTA DE CATALUNYA
 * TREBALL FINAL DE CARRERA - SISTEMES ENCASTATS
 *
 * Jordi Arroyo, 2016
 */


#ifndef AUX_IO_H
#define AUX_IO_H

#include "types.h"
#include "board.h"

/* End & return line for Strings concatenation */
#define ENDRETURN	"\r\n"

/**
 * @brief	Set DEBUG_MODE on or off
 * @param	on	bool true or false
 * @return	None
 */
void setDebugMode( bool on );

/**
 * @brief	Send to DEBUG UART the string
 * @param	pcString	String to send
 * @return	None
 */
void vPrintString( const portCHAR *pcString );

/**
 * @brief	Send to DEBUG UART the string without return end
 * @param	pcString	String to send
 * @return	None
 */
void vPrintStringNoReturn( const portCHAR *pcString );

/**
 * @brief	Send to DEBUG UART the the strings concatenation
 * @param	pcString1 String 1 to concatenate & send
 * @param	pcString2 String 2 to concatenate & send
 * @return	None
 */
void vPrintStringAndString( const portCHAR *pcString1, const portCHAR *pcString2 );

/**
 * @brief	Send to DEBUG UART the string & Integer number concatenation
 * @param	pcString 	String to concatenate & Send
 * @param	ulValue		Long Number to concatenate
 * @return	None
 */
void vPrintStringAndNumber( const portCHAR *pcString, unsigned portLONG ulValue );
/**
 * @brief	Send to DEBUG UART the string & Decimal number concatenation
 * @param	pcString 	String to concatenate & Send
 * @param	ulValue		Decimal Number to concatenate
 * @return	None
 */
void vPrintStringAndDecimal( const portCHAR *pcString, portDOUBLE udValue );

/**
 * @brief	Send to WIFLY UART the string
 * @param	pcString	String to send
 * @return	None
 */
void vSendWiflyString( const portCHAR *pcString );

/**
 * @brief	Send to WIFLY UART the string without return end
 * @param	pcString	String to send
 * @return	None
 */
void vSendWiflyStringNoReturn( const portCHAR *pcString );

/**
 * @brief	Send to WIFLY UART the the strings concatenation
 * @param	pcString1 String 1 to concatenate & send
 * @param	pcString2 String 2 to concatenate & send
 * @return	None
 */
void vSendWiflyStringAndString( const portCHAR *pcString1, const portCHAR *pcString2 );

/**
 * @brief	Send to WIFLY UART the string & Integer number concatenation
 * @param	pcString 	String to concatenate & Send
 * @param	ulValue		Long Number to concatenate
 * @return	None
 */
void vSendWiflyStringAndNumber( const portCHAR *pcString, unsigned portLONG ulValue );

/**
 * @brief	Send to WIFLY UART the string & Decimal number concatenation
 * @param	pcString 	String to concatenate & Send
 * @param	ulValue		Decimal Number to concatenate
 * @return	None
 */
void vSendWiflyStringAndDecimal( const portCHAR *pcString, portDOUBLE udValue );

/*
 * @brief	Read & check response (parameter pattern) from the WIFLY UART
 * 			waiting a maximum of parameter time
 * 			Send to DEBUG UART the read string (if DEBUG_MODE is active)
 * @param	waitedString	pointer to the pattern
 * @param	Time			time Max to wait
 * @return	true if is done
 */
bool checkWiflyResponse( const char *waitedString, uint32_t Time );

/*
 * @brief	Create string with status of the System
 * @param	pcString	pointer to the String
 * @param	state		Status of the System
 * @return	None
 */
void getStringStatusSystem(const char *pcString, SYSTEM_STATUS_T state );

/*
 * @brief	Create string with active INs to the System
 * @param	pcString	pointer to the String
 * @param	statusIN	Status of INs
 * @return	None
 */
void getStringINs(const char *pcString, uint8_t statusIN);

/** Type of execution, must be initialized to use Delay_Ms Function */
TYPE_EXEC_T EXEC_STATUS;

/**
 * @brief	Wait time in execution:
 * @param	base	Mode of delay, Sequential or Task
 * @param	ms 		Milliseconds to delay
 * @return	None
 * @note    Blocking for sequential & vTaskDelay in SO
 * 			Remember to initialize EXEC_STATUS
 */
void Delay_Ms(uint8_t base, uint32_t ms);

#endif /* AUX_IO_H */

