/*
 * @brief wifly.h
 * This handler is for the wifi module
 *
 * @note
 * UNIVERSITAT OBERTA DE CATALUNYA
 * TREBALL FINAL DE CARRERA - SISTEMES ENCASTATS
 *
 * Jordi Arroyo, 2016
 */

#ifndef WIFLY_H_
#define WIFLY_H_

#include "board.h"

/* You need to create this header to use different wifly configuration &
 * define PERSONAL_WIFLY_CONF
 */
#include "iniConfig.h"

/* For not personal configuration Default configuration
 * For change default values create your own PERSONAL_WIFLY_CONF
 * or change this values if not need to keep
 */
#ifndef PERSONAL_WIFLY_CONF
	#define WIFYPASS		"XXXXXXXXXXXXXX"	/* Pass for Wifi SSID */
	#define SSID			"XXXXXXXXXXXX"		/* SSID to Join	*/

	#define UDP				"1"					/* Only UDP connection */
	#define REMOTE_HOST		"192.168.0.100"		/* IP address of remote host */
	#define LOCAL_PORT		"999"				/* Local port */
	#define REMOTE_PORT		"5000"				/* Remote port */

	#define TEST_IP			REMOTE_HOST			/* IP for test ping */
#endif

/* Commands defines */
#define wifiCMD			"$$$"
#define setWifyPASS		"set wlan phrase"
#define JoinWifi		"join"
#define CMDEXIT			"exit"

#define setProtocol 	"set ip protocol"
#define setRemoteHost	"set ip host"
#define setLocalPort	"set ip local"
#define setRemotePort	"set ip remote"
#define SAVE			"save"
#define REBOOT			"reboot"

#define getOWNIP		"get ip"
#define ping			"ping"

/**
 * @brief	Initialize wifly board for Wi-Fi communication
 * @return	true for successful, false for error connection
 */
bool wifly_Init(void);

/**
 * @brief	Initial wifly board configuration for Wi-Fi communication
 * @return	true for successful, false for error connection
 */
bool wifly_Configuration(void);

/**
 * @brief	Reset wifly board
 * @return	None
 */
void resetWifly(void);

/**
 * @brief	Show IP address
 * @return	None
 */
void showIP(void);

/**
 * @brief	Test ping remote device in configurationn as TEST_IP
 * @return	None
 */
void pingTest(void);

#endif /* WIFLY_H_ */
