/*
 * @brief wifly handler
 * This handler is for the wifi module
 *
 * @note
 * UNIVERSITAT OBERTA DE CATALUNYA
 * TREBALL FINAL DE CARRERA - SISTEMES ENCASTATS
 *
 * Jordi Arroyo, 2016
 */

#include "wifly.h"
#include "board.h"
#include "aux_print.h"

//#include "string.h"

/*****************************************************************************
 * Private types/enumerations/variables
 ****************************************************************************/

/*****************************************************************************
 * Public types/enumerations/variables
 ****************************************************************************/

/*****************************************************************************
 * Private functions
 ****************************************************************************/

/* Enable CMD Mode with Wifly Board */
bool WiflyCMD(void)
{
	vSendWiflyStringNoReturn( wifiCMD );
	return checkWiflyResponse( (char *)"CMD", 1000 );
}

/* Disable CMD MOde with Wifly Board */
bool WiflyExitCMD(void)
{
	vSendWiflyString( CMDEXIT );
	return checkWiflyResponse( (char *)"EXIT", 1000 );
}

/* Save configuration in Wifly Board */
bool WiflySave(void)
{
	vSendWiflyString( SAVE );
	return checkWiflyResponse( (char *)"save", 1000 );
}

/* Reboot Wifly Board */
bool WiflyReboot(void)
{
	vSendWiflyString( REBOOT );
	return checkWiflyResponse( (char *)"Reboot", 1000 );
}

/*****************************************************************************
 * Public functions
 ****************************************************************************/

/* Initialize UART board for wifly communication */
bool wifly_Init(void) {

	bool done = false;

	vPrintString( (char *)"Connecting wifly" );

	while (!done) {
		/* Open CMD Mode */
		done = WiflyCMD();

		/* Define pass word to Join */
		if (done) {
			vSendWiflyStringAndString( setWifyPASS, WIFYPASS );
			done = checkWiflyResponse( (char *)"AOK", 1000 );
		}
		/* Join to wifi Net */
		if (done) {
			vSendWiflyStringAndString( JoinWifi, SSID );
			done = checkWiflyResponse( (char *)"IF=UP", 7000 );
		}
		/* Close CMD Mode */
		if (done) {
			done = WiflyExitCMD();
		}
		if (!done) {
			resetWifly();
			vPrintString( (char *)"Error Connecting, Reseting & try again!" );
		}

	}
	vPrintString( (char *)"Wifly Connecting Done!" );

	return done;
}

/* Initial wifly board configuration for Wi-Fi communication */
bool wifly_Configuration(void)
{
	bool done = false;

	vPrintString( (char *)"Configuring initial wifly" );

	while (!done) {
		/* Open CMD Mode */
		done = WiflyCMD();

		/* Set IP protocol as only UDP */
		if (done) {
			vSendWiflyStringAndString( setProtocol, UDP);
			done = checkWiflyResponse( (char *)"AOK", 1000 );
		}
		/* Set IP of the remote host */
		if (done) {
			vSendWiflyStringAndString( setRemoteHost, REMOTE_HOST );
			done = checkWiflyResponse( (char *)"AOK", 1000 );
		}
		/* Set remote host port number */
		if (done) {
			vSendWiflyStringAndString( setRemotePort, REMOTE_PORT );
			done = checkWiflyResponse( (char *)"AOK", 1000 );
		}
		/* Set local host port number */
		if (done) {
			vSendWiflyStringAndString( setLocalPort, LOCAL_PORT );
			done = checkWiflyResponse( (char *)"AOK", 1000 );
		}
		/* Save configuration */
		if (done) {
			done = WiflySave();
		}
		/* Reboot to apply changes */
		if (done) {
			done = WiflyReboot();
		}
		if (!done) {
			resetWifly();
			vPrintString( (char *)"Error Configuring, Reseting & try again!" );
		}
	}
	vPrintString( (char *)"Wifly Configuring Done!" );

	return done;
}

/* reset wifly board */
void resetWifly(void) {
	/* down level for reset */
	OUT_Set( WIFLY_RST, OUT_LOW);
	Delay_Ms( EXEC_STATUS, 500);

	/* high lever for work */
	OUT_Set( WIFLY_RST, OUT_HIGH);
	Delay_Ms( EXEC_STATUS, 500);
}

/* show ip address */
void showIP(void)
{
	/* Open CMD Mode */
	WiflyCMD();

	vSendWiflyString( getOWNIP );
	checkWiflyResponse( (char *)"IP", 1000 );

	/* Close CMD Mode */
	WiflyExitCMD();
}

/* Test ping */
void pingTest(void)
{
	/* Open CMD Mode */
	WiflyCMD();

	vSendWiflyStringAndString( ping, TEST_IP );
	checkWiflyResponse( (char *)"ping", 1000 );

	/* Close CMD Mode */
	WiflyExitCMD();
}
